@@ -12,7 +12,7 @@
 
 -- |
 -- Module      :  Test.ChasingBottoms.ContinuousFunctions
--- Copyright   :  (c) Nils Anders Danielsson 2005-2018
+-- Copyright   :  (c) Nils Anders Danielsson 2005-2019
 -- License     :  See the file LICENCE.
 --
 -- Maintainer  :  http://www.cse.chalmers.se/~nad/
@@ -146,16 +146,11 @@ module Test.ChasingBottoms.ContinuousFunctions
 import Test.QuickCheck
   hiding ( (><)
          , listOf
-#if MIN_VERSION_QuickCheck(2,7,0)
          , infiniteListOf
-#endif
-#if MIN_VERSION_QuickCheck(2,10,0)
          , function
-#endif
          )
-#if MIN_VERSION_QuickCheck(2,7,0)
+import Test.QuickCheck.Arbitrary (CoArbitrary(..))
 import Test.QuickCheck.Gen.Unsafe (promote)
-#endif
 import Data.Sequence as Seq
 import Data.Foldable as Seq (foldr)
 import Prelude as P hiding (concat)
