@@ -39,11 +39,7 @@ import Text.Show.Functions
 
 run :: Testable p => p -> IO Result
 run = quickCheckWithResult (stdArgs { maxSuccess = 1000
-#if MIN_VERSION_QuickCheck(2,5,0)
                                     , maxDiscardRatio = 5
-#else
-                                    , maxDiscard = 5000
-#endif
                                     })
 
 -- | Runs a bunch of QuickCheck tests, printing suitable information
